@@ -42,7 +42,8 @@ case "$1" in
 
         VARCHIVE=$(echo "$SYSTEMINFO"|tr -d '()'|grep bennoarchive|cut -d ' ' -f 3)
         VCORE=$(echo "$SYSTEMINFO" |tr -d '()'|grep bennocore|cut -d ' ' -f 3)
-        IPATTERN=$(/bin/echo "$SYSTEMINFO"|grep ImportPattern|perl -p -e 's/ImportPattern:\s+//')
+        IMPORTSERVICE=$(/bin/echo -e 'list services\nquit'|nc localhost 2555 2>/dev/null)
+        IPATTERN=$(/bin/echo "$IMPORTSERVICE"|grep -m1 ImportPattern|perl -p -e 's/ImportPattern:\s+//')
         if [ "${IPATTERN}x" != x ];then
             INBOXDIR=$(dirname "$IPATTERN")
         else
